@@ -33,13 +33,12 @@
 
 #include "../EffectBase.h"
 
-#include <cmath>
-#include <stdio.h>
-#include <memory>
-#include "../Color.h"
+#include "../Frame.h"
 #include "../Json.h"
 #include "../KeyFrame.h"
 
+#include <memory>
+#include <string>
 
 namespace openshot
 {
@@ -64,10 +63,10 @@ namespace openshot
 		Keyframe right;			///< Size of right margin
 		Keyframe bottom;		///< Size of bottom margin
 
-		/// Blank constructor, useful when using Json to load the effect properties
+		/// Default constructor, useful when using Json to load the effect properties
 		Pixelate();
 
-		/// Default constructor, which takes 5 curves. These curves animate the pixelization effect over time.
+		/// Cnstructor which takes 5 curves. These curves animate the pixelization effect over time.
 		///
 		/// @param pixelization The curve to adjust the amount of pixelization (0 to 1)
 		/// @param left The curve to adjust the left margin size (between 0 and 1)
@@ -76,22 +75,30 @@ namespace openshot
 		/// @param bottom The curve to adjust the bottom margin size (between 0 and 1)
 		Pixelate(Keyframe pixelization, Keyframe left, Keyframe top, Keyframe right, Keyframe bottom);
 
-		/// @brief This method is required for all derived classes of EffectBase, and returns a
+		/// @brief This method is required for all derived classes of ClipBase, and returns a
+		/// new openshot::Frame object. All Clip keyframes and effects are resolved into
+		/// pixels.
+		///
+		/// @returns A new openshot::Frame object
+		/// @param frame_number The frame number (starting at 1) of the clip or effect on the timeline.
+		std::shared_ptr<openshot::Frame> GetFrame(int64_t frame_number) override { return GetFrame(std::make_shared<openshot::Frame>(), frame_number); }
+
+		/// @brief This method is required for all derived classes of ClipBase, and returns a
 		/// modified openshot::Frame object
 		///
-		/// The frame object is passed into this method, and a frame_number is passed in which
-		/// tells the effect which settings to use from its keyframes (starting at 1).
+		/// The frame object is passed into this method and used as a starting point (pixels and audio).
+		/// All Clip keyframes and effects are resolved into pixels.
 		///
 		/// @returns The modified openshot::Frame object
-		/// @param frame The frame object that needs the effect applied to it
-		/// @param frame_number The frame number (starting at 1) of the effect on the timeline.
-		std::shared_ptr<Frame> GetFrame(std::shared_ptr<Frame> frame, int64_t frame_number);
+		/// @param frame The frame object that needs the clip or effect applied to it
+		/// @param frame_number The frame number (starting at 1) of the clip or effect on the timeline.
+		std::shared_ptr<openshot::Frame> GetFrame(std::shared_ptr<openshot::Frame> frame, int64_t frame_number) override;
 
-		/// Get and Set JSON methods
+		// Get and Set JSON methods
 		std::string Json() const override; ///< Generate JSON string of this object
-		void SetJson(const std::string value); ///< Load JSON string into this object
+		void SetJson(const std::string value) override; ///< Load JSON string into this object
 		Json::Value JsonValue() const override; ///< Generate Json::Value for this object
-		void SetJsonValue(const Json::Value root); ///< Load Json::Value into this object
+		void SetJsonValue(const Json::Value root) override; ///< Load Json::Value into this object
 
 		/// Get all properties for a specific frame (perfect for a UI to display the current state
 		/// of all properties at any time)
